;+
; Procedure:    netcdf2tplot
; 
; Input:
;         files: netCDF files to be loaded
;         
; Keywords:
;         verbose: request more verbose output
;
; $LastChangedBy: egrimes $
; $LastChangedDate: 2013-07-29 11:12:10 -0700 (Mon, 29 Jul 2013) $
; $LastChangedRevision: 12739 $
; $URL: svn+ssh://thmsvn@ambrosia.ssl.berkeley.edu/repos/ssl_general/trunk/netCDF/netcdf2tplot.pro $
;-

pro netcdf2tplot, files, verbose=verbose
    ; check that netCDF is supported
    if ncdf_exists() eq 0 then begin
        dprint, 'netCDF not supported by the current IDL installation.'
        return
    endif

    ; load the netCDF file into an IDL struct
    ; this routine should work with any netCDF file, 
    ; regardless of the format of the data
    netCDFi = netcdf_load_vars(files)
    if size(netCDFi, /type) ne 8 then begin
        dprint, dlevel = 1, 'netCDFi was invalid. Trouble loading the netCDF file into an IDL structure.'
        return
    endif 
    
    ; change the previously created struct into 
    ; a struct readable by cdf_info_to_tplot
    cdf_struct = GOESstruct_to_cdfstruct(netCDFi)
    
    if size(cdf_struct, /type) ne 8 then begin
        dprint, dlevel = 1, 'cdf_struct was invalid. Trouble converting the netCDF IDL structure into a standard CDF structure.'
        return
    endif
    
    ; create tplot variables from the struct
    cdf_info_to_tplot, cdf_struct, verbose = verbose
end
